@@ -1,4 +1,4 @@
 #!/bin/sh
 # run python interpreter with current dir as search path, and remove all
 # locale and proxy settings
-env -u ftp_proxy -u http_proxy -u LANGUAGE -u LC_ALL -u LC_CTYPE LANG=C PYTHONPATH=`pwd` python $*
+env -u ftp_proxy -u http_proxy -u LANGUAGE -u LC_ALL -u LC_CTYPE LANG=C PYTHONPATH=`pwd` python2.3 $*
